@@ -1,7 +1,7 @@
 /*
  *  db.h
  *
- *  Copyright (c) 2006-2010 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2011 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2006 by Miklos Vajna <vmiklos@frugalware.org>
@@ -23,22 +23,31 @@
 #define _ALPM_DB_H
 
 #include "alpm.h"
-#include <limits.h>
+#include "pkghash.h"
+
 #include <time.h>
 
+/* libarchive */
+#include <archive.h>
+#include <archive_entry.h>
+
 /* Database entries */
 typedef enum _pmdbinfrq_t {
 	INFRQ_BASE = 1,
 	INFRQ_DESC = (1 << 1),
-	INFRQ_DEPENDS = (1 << 2),
-	INFRQ_FILES = (1 << 3),
-	INFRQ_SCRIPTLET = (1 << 4),
-	INFRQ_DELTAS = (1 << 5),
-	INFRQ_DSIZE = (1 << 6),
+	INFRQ_FILES = (1 << 2),
+	INFRQ_SCRIPTLET = (1 << 3),
+	INFRQ_DSIZE = (1 << 4),
 	/* ALL should be info stored in the package or database */
-	INFRQ_ALL = 0x3F
+	INFRQ_ALL = 0x1F
 } pmdbinfrq_t;
 
+struct db_operations {
+	int (*populate) (pmdb_t *);
+	void (*unregister) (pmdb_t *);
+	int (*version) (pmdb_t *);
+};
+
 /* Database */
 struct __pmdb_t {
 	char *treename;
@@ -46,26 +55,48 @@ struct __pmdb_t {
 	char *_path;
 	int pkgcache_loaded;
 	int grpcache_loaded;
+	/* also indicates whether we are RO or RW */
 	int is_local;
-	alpm_list_t *pkgcache;
+	pmpkghash_t *pkgcache;
 	alpm_list_t *grpcache;
 	alpm_list_t *servers;
+
+	struct db_operations *ops;
 };
 
+
 /* db.c, database general calls */
+pmdb_t *_alpm_db_new(const char *treename, int is_local);
 void _alpm_db_free(pmdb_t *db);
 const char *_alpm_db_path(pmdb_t *db);
+int _alpm_db_version(pmdb_t *db);
 int _alpm_db_cmp(const void *d1, const void *d2);
 alpm_list_t *_alpm_db_search(pmdb_t *db, const alpm_list_t *needles);
 pmdb_t *_alpm_db_register_local(void);
 pmdb_t *_alpm_db_register_sync(const char *treename);
+void _alpm_db_unregister(pmdb_t *db);
 
-/* be.c, backend specific calls */
-int _alpm_db_populate(pmdb_t *db);
-int _alpm_db_read(pmdb_t *db, pmpkg_t *info, pmdbinfrq_t inforeq);
-int _alpm_db_prepare(pmdb_t *db, pmpkg_t *info);
-int _alpm_db_write(pmdb_t *db, pmpkg_t *info, pmdbinfrq_t inforeq);
-int _alpm_db_remove(pmdb_t *db, pmpkg_t *info);
+/* be_*.c, backend specific calls */
+int _alpm_local_db_read(pmdb_t *db, pmpkg_t *info, pmdbinfrq_t inforeq);
+int _alpm_local_db_prepare(pmdb_t *db, pmpkg_t *info);
+int _alpm_local_db_write(pmdb_t *db, pmpkg_t *info, pmdbinfrq_t inforeq);
+int _alpm_local_db_remove(pmdb_t *db, pmpkg_t *info);
+
+/* cache bullshit */
+/* packages */
+int _alpm_db_load_pkgcache(pmdb_t *db);
+void _alpm_db_free_pkgcache(pmdb_t *db);
+int _alpm_db_add_pkgincache(pmdb_t *db, pmpkg_t *pkg);
+int _alpm_db_remove_pkgfromcache(pmdb_t *db, pmpkg_t *pkg);
+pmpkghash_t *_alpm_db_get_pkgcache_hash(pmdb_t *db);
+alpm_list_t *_alpm_db_get_pkgcache(pmdb_t *db);
+int _alpm_db_ensure_pkgcache(pmdb_t *db, pmdbinfrq_t infolevel);
+pmpkg_t *_alpm_db_get_pkgfromcache(pmdb_t *db, const char *target);
+/* groups */
+int _alpm_db_load_grpcache(pmdb_t *db);
+void _alpm_db_free_grpcache(pmdb_t *db);
+alpm_list_t *_alpm_db_get_grpcache(pmdb_t *db);
+pmgrp_t *_alpm_db_get_grpfromcache(pmdb_t *db, const char *target);
 
 #endif /* _ALPM_DB_H */
 
