@@ -1,7 +1,7 @@
 /*
  *  handle.h
  *
- *  Copyright (c) 2006-2010 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2011 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@ typedef struct _pmhandle_t {
 	pmdb_t *db_local;       /* local db pointer */
 	alpm_list_t *dbs_sync;  /* List of (pmdb_t *) */
 	FILE *logstream;        /* log file stream pointer */
-	int lckfd;              /* lock file descriptor if one exists */
+	FILE *lckstream;        /* lock file stream pointer if one exists */
 	pmtrans_t *trans;
 
 	/* callback functions */
@@ -60,12 +60,13 @@ typedef struct _pmhandle_t {
 	int usesyslog;    /* Use syslog instead of logfile? */ /* TODO move to frontend */
 	char *arch;       /* Architecture of packages we should allow */
 	int usedelta;     /* Download deltas if possible */
+	int checkspace;   /* Check disk space before installing */
 } pmhandle_t;
 
 /* global handle variable */
 extern pmhandle_t *handle;
 
-pmhandle_t *_alpm_handle_new();
+pmhandle_t *_alpm_handle_new(void);
 void _alpm_handle_free(pmhandle_t *handle);
 
 #endif /* _ALPM_HANDLE_H */
