@@ -746,8 +746,9 @@ static int multiselect_parse(char *array, int count, char *response)
 		char *ends = NULL;
 		char *starts = strtok_r(str, " ", &saveptr);
 
-		if (starts == NULL)
+		if (starts == NULL) {
 			break;
+		}
 		strtrim(starts);
 		int len = strlen(starts);
 		if(len == 0)
@@ -765,9 +766,9 @@ static int multiselect_parse(char *array, int count, char *response)
 		if(len > 1) {
 			/* check for range */
 			char *p;
-			if((p = strchr(starts+1, '-'))) {
+			if((p = strchr(starts + 1, '-'))) {
 				*p = 0;
-				ends = p+1;
+				ends = p + 1;
 			}
 		}
 
@@ -777,9 +778,11 @@ static int multiselect_parse(char *array, int count, char *response)
 		if(!ends) {
 			array[start-1] = include;
 		} else {
-			if(parseindex(ends, &end, start, count) != 0)
+			int d;
+			if(parseindex(ends, &end, start, count) != 0) {
 				return(-1);
-			for(int d = start; d <= end; d++) {
+			}
+			for(d = start; d <= end; d++) {
 				array[d-1] = include;
 			}
 		}
@@ -878,6 +881,10 @@ static int question(short preset, char *fmt, va_list args)
 		stream = stderr;
 	}
 
+	/* ensure all text makes it to the screen before we prompt the user */
+	fflush(stdout);
+	fflush(stderr);
+
 	vfprintf(stream, fmt, args);
 
 	if(preset) {
@@ -891,6 +898,7 @@ static int question(short preset, char *fmt, va_list args)
 		return(preset);
 	}
 
+	fflush(stream);
 	if(fgets(response, sizeof(response), stdin)) {
 		strtrim(response);
 		if(strlen(response) == 0) {
