@@ -1,7 +1,7 @@
 /*
  *  util.h
  *
- *  Copyright (c) 2006-2010 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2011 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -30,8 +30,10 @@
 #include <libintl.h> /* here so it doesn't need to be included elsewhere */
 /* define _() as shortcut for gettext() */
 #define _(str) gettext(str)
+#define _n(str1, str2, ct) ngettext(str1, str2, ct)
 #else
 #define _(str) str
+#define _n(str1, str2, ct) (ct == 1 ? str1 : str2)
 #endif
 
 /* update speed for the fill_progress based functions */
@@ -42,7 +44,7 @@ int trans_release(void);
 int needs_root(void);
 int getcols(void);
 int rmrf(const char *path);
-char *mbasename(const char *path);
+const char *mbasename(const char *path);
 char *mdirname(const char *path);
 void indentprint(const char *str, int indent);
 char *strtoupper(char *str);
@@ -53,13 +55,18 @@ void string_display(const char *title, const char *string);
 void list_display(const char *title, const alpm_list_t *list);
 void list_display_linebreak(const char *title, const alpm_list_t *list);
 void display_targets(const alpm_list_t *pkgs, int install);
+int str_cmp(const void *s1, const void *s2);
 void display_new_optdepends(pmpkg_t *oldpkg, pmpkg_t *newpkg);
 void display_optdepends(pmpkg_t *pkg);
 void print_packages(const alpm_list_t *packages);
+void select_display(const alpm_list_t *pkglist);
+int select_question(int count);
+int multiselect_question(char *array, int count);
 int yesno(char *fmt, ...);
 int noyes(char *fmt, ...);
 int pm_printf(pmloglevel_t level, const char *format, ...) __attribute__((format(printf,2,3)));
 int pm_fprintf(FILE *stream, pmloglevel_t level, const char *format, ...) __attribute__((format(printf,3,4)));
+int pm_asprintf(char **string, const char *format, ...);
 int pm_vfprintf(FILE *stream, pmloglevel_t level, const char *format, va_list args) __attribute__((format(printf,3,0)));
 int pm_vasprintf(char **string, pmloglevel_t level, const char *format, va_list args) __attribute__((format(printf,3,0)));
 
