@@ -15,6 +15,6 @@ self.addrule("PACMAN_RETCODE=0")
 self.addrule("PACMAN_OUTPUT=" + pre)
 self.addrule("PACMAN_OUTPUT=" + post)
 
-fakechroot = which("fakechroot")
+fakechroot = util.which("fakechroot")
 if not fakechroot:
 	self.expectfailure = True
